@@ -1,7 +1,7 @@
 package App::dateseq;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-09-25'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,19 +27,19 @@ _
         from => {
             summary => 'Starting date',
             schema => 'date*',
-            'x.perl.coerce_to_datetime_obj' => 1,
+            'x.perl.coerce_to' => 'DateTime',
             req => 1,
             pos => 0,
         },
         to => {
             summary => 'End date, if not specified will generate an infinite* stream of dates',
             schema => 'date*',
-            'x.perl.coerce_to_datetime_obj' => 1,
+            'x.perl.coerce_to' => 'DateTime',
             pos => 1,
         },
         increment => {
             schema => 'duration*',
-            'x.perl.coerce_to_datetime_duration_obj' => 1,
+            'x.perl.coerce_to' => 'DateTime::Duration',
             cmdline_aliases => {i=>{}},
             pos => 2,
         },
@@ -181,14 +181,14 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.03 of App::dateseq (from Perl distribution App-dateseq), released on 2015-08-18.
+This document describes version 0.04 of App::dateseq (from Perl distribution App-dateseq), released on 2015-09-25.
 
 =head1 FUNCTIONS
 
 
 =head2 dateseq(%args) -> [status, msg, result, meta]
 
-{en_US Generate a sequence of dates}.
+Generate a sequence of dates.
 
 Examples:
 
@@ -234,10 +234,8 @@ List non-holidays business days in 2015 (using Indonesian holidays).
 Use with fsql.
 
 
-{en_US 
 This utility is similar to Unix C<seq> command, except that it generates a
 sequence of dates.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -245,33 +243,33 @@ Arguments ('*' denotes required arguments):
 
 =item * B<business> => I<bool>
 
-{en_US Only list business days (Mon-Fri)}.
+Only list business days (Mon-Fri).
 
 =item * B<business6> => I<bool>
 
-{en_US Only list business days (Mon-Sat)}.
+Only list business days (Mon-Sat).
 
 =item * B<date_format> => I<str>
 
-{en_US strftime() format for each date}.
+strftime() format for each date.
 
 =item * B<from>* => I<date>
 
-{en_US Starting date}.
+Starting date.
 
 =item * B<header> => I<str>
 
-{en_US Add a header row}.
+Add a header row.
 
 =item * B<increment> => I<duration>
 
 =item * B<limit> => I<int>
 
-{en_US Only generate a certain amount of numbers}.
+Only generate a certain amount of numbers.
 
 =item * B<to> => I<date>
 
-{en_US End date, if not specified will generate an infinite* stream of dates}.
+End date, if not specified will generate an infinite* stream of dates.
 
 =back
 
